@@ -154,18 +154,18 @@ mod tests {
     use crate::core_arch::x86::*;
 
     #[simd_test(enable = "tbm")]
-    unsafe fn test_bextri_u32() {
+    fn test_bextri_u32() {
         assert_eq!(_bextri_u32::<0x0404>(0b0101_0000u32), 0b0000_0101u32);
     }
 
     #[simd_test(enable = "tbm")]
-    const unsafe fn test_blcfill_u32() {
+    const fn test_blcfill_u32() {
         assert_eq!(_blcfill_u32(0b0101_0111u32), 0b0101_0000u32);
         assert_eq!(_blcfill_u32(0b1111_1111u32), 0u32);
     }
 
     #[simd_test(enable = "tbm")]
-    const unsafe fn test_blci_u32() {
+    const fn test_blci_u32() {
         assert_eq!(
             _blci_u32(0b0101_0000u32),
             0b1111_1111_1111_1111_1111_1111_1111_1110u32
@@ -177,25 +177,25 @@ mod tests {
     }
 
     #[simd_test(enable = "tbm")]
-    const unsafe fn test_blcic_u32() {
+    const fn test_blcic_u32() {
         assert_eq!(_blcic_u32(0b0101_0001u32), 0b0000_0010u32);
         assert_eq!(_blcic_u32(0b1111_1111u32), 0b1_0000_0000u32);
     }
 
     #[simd_test(enable = "tbm")]
-    const unsafe fn test_blcmsk_u32() {
+    const fn test_blcmsk_u32() {
         assert_eq!(_blcmsk_u32(0b0101_0001u32), 0b0000_0011u32);
         assert_eq!(_blcmsk_u32(0b1111_1111u32), 0b1_1111_1111u32);
     }
 
     #[simd_test(enable = "tbm")]
-    const unsafe fn test_blcs_u32() {
+    const fn test_blcs_u32() {
         assert_eq!(_blcs_u32(0b0101_0001u32), 0b0101_0011u32);
         assert_eq!(_blcs_u32(0b1111_1111u32), 0b1_1111_1111u32);
     }
 
     #[simd_test(enable = "tbm")]
-    const unsafe fn test_blsfill_u32() {
+    const fn test_blsfill_u32() {
         assert_eq!(_blsfill_u32(0b0101_0100u32), 0b0101_0111u32);
         assert_eq!(
             _blsfill_u32(0u32),
@@ -204,7 +204,7 @@ mod tests {
     }
 
     #[simd_test(enable = "tbm")]
-    const unsafe fn test_blsic_u32() {
+    const fn test_blsic_u32() {
         assert_eq!(
             _blsic_u32(0b0101_0100u32),
             0b1111_1111_1111_1111_1111_1111_1111_1011u32
@@ -216,7 +216,7 @@ mod tests {
     }
 
     #[simd_test(enable = "tbm")]
-    const unsafe fn test_t1mskc_u32() {
+    const fn test_t1mskc_u32() {
         assert_eq!(
             _t1mskc_u32(0b0101_0111u32),
             0b1111_1111_1111_1111_1111_1111_1111_1000u32
@@ -228,7 +228,7 @@ mod tests {
     }
 
     #[simd_test(enable = "tbm")]
-    const unsafe fn test_tzmsk_u32() {
+    const fn test_tzmsk_u32() {
         assert_eq!(_tzmsk_u32(0b0101_1000u32), 0b0000_0111u32);
         assert_eq!(_tzmsk_u32(0b0101_1001u32), 0b0000_0000u32);
     }
